@@ -57,7 +57,6 @@ static void fmtx_faker_finalize (GObject *object)
 {
 	FMTXFaker *self = FMTX_FAKER (object);
 	FMTXFakerPrivate *priv = FMTX_FAKER_GET_PRIVATE (self);
-	guint release_name_ret;
 
 	if (priv->bus_proxy)
 	{
@@ -173,34 +172,77 @@ static gboolean fmtx_faker_shutdown (GObject *self)
 }
 
 /* D-Bus, eh? */
-gboolean fmtx_faker_get_config_value (FMTXFaker *self, const gchar *string, GArray **out_array, GError **error G_GNUC_UNUSED)
+gboolean fmtx_faker_get_config_value (FMTXFaker *self, const gchar *string, GArray **out_array, GError **error)
 {
-	/* TODO: Implement passthrough method */
-	if (G_LIKELY (string) && G_LIKELY (!strcmp (string, "/certs/ccc/pp/fmtx-raw")))
+	gboolean retval = FALSE;
+
+	if (G_LIKELY (!g_strcmp0 (string, "/certs/ccc/pp/fmtx-raw")))
 	{
 		FMTXFakerPrivate *priv = FMTX_FAKER_GET_PRIVATE (self);
 		const guchar terminator = 0;
 
 		if (G_UNLIKELY (!priv))
-			goto ret_false;
+		{
+			g_set_error (error, DBUS_GERROR, DBUS_GERROR_REMOTE_EXCEPTION, "FMTX Faker Int. Error: Couldn't retrieve private struct");
+			goto ret;
+		}
 
 		*out_array = g_array_sized_new (FALSE, FALSE, sizeof (guchar), 2);
 		if (!*out_array)
-			goto ret_false;
+		{
+			g_set_error (error, DBUS_GERROR, DBUS_GERROR_REMOTE_EXCEPTION, "FMTX Faker Int. Error: Unable to create GArray");
+			goto ret;
+		}
 
 		g_array_append_val (*out_array, priv->fmtx_mode);
 		g_array_append_val (*out_array, terminator); /* Hasta la vista, baby */
 
-		g_idle_add ((GSourceFunc) fmtx_faker_shutdown, self);
-
-		return TRUE;
+		retval = TRUE;
 	}
-	else
-		goto ret_false;
+	else /* We've been invoked for another key. Awesomeness! Based on code from hildon-control-panel */
+	{
+		#define SYSINFO_SERVICE_DBUS "com.nokia.SystemInfo"
+		#define SYSINFO_PATH_DBUS "/com/nokia/SystemInfo"
+		#define SYSINFO_INTERFACE_DBUS "com.nokia.SystemInfo"
+		#define SYSINFO_METHOD "GetConfigValue"		
 
-ret_false:
+		DBusGConnection  *sys_connection;
+		DBusGProxy *sysinfo_proxy;
+		GError *tmp_error = NULL; 
+		
+		sys_connection = dbus_g_bus_get (DBUS_BUS_SYSTEM, &tmp_error);
+		if (tmp_error)
+		{
+			g_propagate_error (error, tmp_error);
+			goto ret;
+		}
+
+		sysinfo_proxy = dbus_g_proxy_new_for_name (sys_connection, SYSINFO_SERVICE_DBUS, SYSINFO_PATH_DBUS, SYSINFO_INTERFACE_DBUS);
+		if (!sysinfo_proxy)
+		{
+			dbus_g_connection_unref (sys_connection);
+			g_set_error (error, DBUS_GERROR, DBUS_GERROR_REMOTE_EXCEPTION, "Couldn't create SystemInfo proxy");
+			goto ret;
+		}
+		
+		dbus_g_proxy_call (sysinfo_proxy, SYSINFO_METHOD, &tmp_error, G_TYPE_STRING, string, G_TYPE_INVALID, dbus_g_type_get_collection ("GArray", G_TYPE_UCHAR), out_array, G_TYPE_INVALID);
+		if (tmp_error)
+		{
+			g_object_unref (G_OBJECT (sysinfo_proxy));
+			dbus_g_connection_unref (sys_connection);
+			g_propagate_error (error, tmp_error);
+			goto ret;
+		}
+
+		g_object_unref (G_OBJECT (sysinfo_proxy));
+		dbus_g_connection_unref (sys_connection);
+
+		retval = TRUE;
+	}
+
+ret:
 	g_idle_add ((GSourceFunc) fmtx_faker_shutdown, self);
-	g_return_val_if_reached (FALSE);
+	g_return_val_if_reached (retval);
 }
 
 FMTXFaker* fmtx_faker_new_with_fmtx_mode_property (const guchar value)
